@@ -6,17 +6,22 @@ package Data::Random::Weighted;
 
 use strict;
 use warnings;
-use Exporter 'import';
-our @EXPORT_OK = qw( randomizer );
+
+sub new {
+    my $class = shift;
+    my $args  = shift || {};
+    my $self  = bless {}, $class;
+    $self->{'roller'} = $self->randomizer($args);
+    return $self;
+}
 
 sub randomizer {
-    my $args = shift;
-    my $total;
-    $total += $_ for values %$args;
-    my $weight;
+    my ( $self, $args ) = @_;
+    my ( $weight, $total );
     my $count = 0;
     for my $key( keys %$args ) {
         my $set = $args->{$key};
+        $total += $set;
         for ( 1 .. $set ) {
             $weight->{$count++} = $key;
         }
@@ -27,6 +32,7 @@ sub randomizer {
     }
 }
 
+sub roll { &{ shift->{'roller'} }() }
 
 1;
 
@@ -42,7 +48,7 @@ Data::Random::Weighted - get weighted random data
 
 =head1 VERSION
 
-version 0.002
+version 1.000
 
 =head1 Data::Random::Weighted
 
@@ -50,25 +56,12 @@ Used to return random results from a weighted set.
 
 =head1 Usage
 
-my $rand = randomizer({
+my $rand = Data::Random::Weighter->new({
     'Result' => 5,
     42       => 1,
-});
+ });
 
-print &$rand;
-
-=head2 Signature
-
-            .’│_.-
-          .’  ’  /_
-       .-"    -.   ’>
-    .- -. -.    ’. /    /│_
-   .-.--.-.       ’ >  /  /
-  (o( o( o )       \_."  <
-   ’-’-’’-’            ) <
- (       _.-’-.   ._\.  _\
-  ’----"/--.__.-) _-  \│
- AoS    "V""    "V"
+print $rand->roll;
 
 =head1 AUTHOR
 
